% Specification of previous and new data, and of the regression model
data=load('d1-data.txt');
ind=data(:,3)==2;  data_new=data(ind,:); 
data_prior=data; data_prior(ind,:)=[]; 
ind_meas=[4,5,6,19,20,21,25,26,27]; 
data_meas=data_new(ind_meas,:); 
data_new(ind_meas,:)=[]; 
xnew1=0.002;     % new x-value(s) for prediction
exponents=[0,1]; % regression model
scale=1;         % flag for scaling of designmatrix, 0 => no scaling
prop=0.95;       % credible interval probability 

ystr='effective area in mm^2'; xstr='$$1/\sqrt{Re}$$';
format compact; format shortE;

% determine NIG prior from previous measurements
figure(4); clf;
[theta0,V0,alp0,bet0,NIG_priors] = BayesLR_Prior(data_prior,exponents,scale,prop);
xlabel(xstr,'interpreter','latex'); ylabel(ystr);   data_axis=axis();
disp('NIG-Prior'); disp([theta0',alp0,bet0]); disp(V0); disp(' ');  
figure(3); clf;
BayesLR_PlotDensity(theta0,V0,alp0,bet0,'kg',NIG_priors);
legend({'NIG Prior','past knowledge','past estimates'},'box','off','fontsize',8);

% NIG-posterior
[theta,V,alp,bet] = BayesLR_NIG_Posterior(theta0,V0,alp0,bet0,data_meas,exponents,scale);
disp('NIG-Posterior');
disp([theta',alp,bet]); disp(V);  disp(' ');
Xnew1=BayesLR_Designmatrix(xnew1,exponents,0);
estim=BayesLR_Estimates(theta,V,alp,bet,prop);
pred=BayesLR_Prediction(theta,V,alp,bet,Xnew1,prop);
disp('Posterior estimates');
disp(estim); disp('Prediction'); disp(pred); disp(' ');
figure(6); clf;
density_ranges=BayesLR_PlotDensity(theta,V,alp,bet);  
BayesLR_PlotDensity(theta0,V0,alp0,bet0,'r');  legend({'NIG Post.','NIG Prior'},'box','off','fontsize',8);
figure(7); clf;
xd=data_meas(:,1); yd=data_meas(:,2);
plot(xd,yd,'or'); xlabel(xstr,'interpreter','latex'); ylabel(ystr);
hold on; 
xx=linspace(min(data_prior(:,1)),max(data_prior(:,1)),500)'; XX=BayesLR_Designmatrix(xx,exponents,0);
BayesLR_PlotModel(xx,XX,theta,V,alp,bet,prop,'r'); 
errorbar(xnew1,pred(:,1),pred(:,1)-pred(:,3),pred(:,4)-pred(:,1),'*r');
hold off;
legend({'Data','Post. regression','Post. prediction'},'box','off','fontsize',8); axis(data_axis);

% sensitivity analysis
theta0A=theta0; V0A=2*V0; alp0A=2.77; bet0A=0.002;
[thetaA,VA,alpA,betA] = BayesLR_NIG_Posterior(theta0A,V0A,alp0A,bet0A,data_meas,exponents,scale);
[thetaC,VC,alpC,betC] = BayesLR_Noninf_Posterior(data_meas,exponents,scale);
predA=BayesLR_Prediction(thetaA,VA,alpA,betA,Xnew1);
predC=BayesLR_Prediction(thetaC,VC,alpC,betC,Xnew1);
disp('Sensitivity analysis');
disp(BayesLR_Estimates(thetaA,VA,alpA,betA)); disp(predA); disp(' ');
disp(BayesLR_Estimates(thetaC,VC,alpC,betC)); disp(predC); disp(' ');

figure(8);
BayesLR_PlotDensity(theta0,V0,alp0,bet0);  
BayesLR_PlotDensity(theta0A,V0A,alp0A,bet0A,'g'); 
BayesLR_PlotDensity(theta,V,alp,bet,'r'); 
BayesLR_PlotDensity(thetaA,VA,alpA,betA,'b'); 
BayesLR_PlotDensity(thetaC,VC,alpC,betC,'m'); 
legend({'NIG prior','Prior A','NIG Posterior','Post. (Prior A)','Post. (Prior C)'},'box','off','fontsize',8);
for k=1:numel(theta); subplot(1,numel(theta)+1,k); xlim(density_ranges(k,:)); end;

figure(9); clf;  pos=get(gcf,'position'); set(gcf,'position',pos+[0,0,400*(pos(3)<600),0]);
for k=1:2;
subplot(1,2,k);
plot(xd,yd,'or'); xlabel(xstr,'interpreter','latex'); ylabel(ystr);  small_axis=axis();
hold on; 
errorbar(xnew1,pred(:,1),pred(:,1)-pred(:,3),pred(:,4)-pred(:,1),'*r');
errorbar(xnew1,predA(:,1),predA(:,1)-predA(:,3),predA(:,4)-predA(:,1),'*b','HandleVisibility','off');
errorbar(xnew1,predC(:,1),predC(:,1)-predC(:,3),predC(:,4)-predC(:,1),'*m','HandleVisibility','off');
BayesLR_PlotModel(xx,XX,theta,V,alp,bet,prop,'r'); 
BayesLR_PlotModel(xx,XX,thetaA,VA,alpA,betA,prop,'b'); 
BayesLR_PlotModel(xx,XX,thetaC,VC,alpC,betC,prop,'m'); 
hold off; 
if k==1; axis(data_axis); 
    legend({'data','Post pred','NIG Post','Post (Prior A)','Post (Prior C)'},'box','off','fontsize',8);
  else; axis(small_axis); xlim(xlim()+0.2*diff(xlim())*[-1,1]); 
    ylim(ylim()+0.2*diff(ylim())*[-1,1]); end
end

% model check
xadd=data_new(:,1); yadd=data_new(:,2);
predadd=BayesLR_Prediction(theta,V,alp,bet,BayesLR_Designmatrix(xadd,exponents,0),prop);
figure(10); plot(xadd,yadd,'ob'); xlabel(xstr,'interpreter','latex'); ylabel(ystr);
hold on; errorbar(xadd,predadd(:,1),predadd(:,1)-predadd(:,3),predadd(:,4)-predadd(:,1),'*r');
hold off
legend({'Additional data','Post. prediction'},'box','off','fontsize',8); axis(data_axis);

preddata=BayesLR_Prediction(theta,V,alp,bet,BayesLR_Designmatrix(xd,exponents,0),prop);
figure(11);
plot(xd,yd-preddata(:,1),'or'); xlabel(xstr,'interpreter','latex'); ylabel('residuals');
hold on;
for k=1:numel(yd);   plot(xd*[1 1],(preddata(k,1)-preddata(k,3))*[-1,1],'-r'); end;
hold off;
legend({'realized residuals','predicted residuals'},'box','off','fontsize',8);
xlim(xlim()+0.1*diff(xlim())*[-1,1]); ylim(ylim()+0.2*diff(ylim())*[0,1]);

% -------------------------------------------------------------------------
% No warranty or guarantee applies to this software, and therefore any 
% users should satisfy themselves that it meets their requirements.
% -------------------------------------------------------------------------

